@@ -10,6 +10,7 @@ import os
 import os.path
 import __main__
 import multiprocessing
+import webbrowser
 from statistics import stdev
 from typing import Dict, Iterable, Optional, List
 
@@ -27,7 +28,10 @@ from canalyst_candas import settings
 from canalyst_candas.candas.func_music import FuncMusic
 from canalyst_candas.datafunctions import DataFunctions
 from canalyst_candas.configuration.config import Config, create_config
-from canalyst_candas.exceptions import ScenarioException, CSINEmptyException
+from canalyst_candas.exceptions import (
+    ScenarioException,
+    CSINEmptyException,
+)
 from canalyst_candas.utils.logger import LogFile
 from canalyst_candas.utils.transformations import (
     filter_dataset,
@@ -317,13 +321,6 @@ class ModelMap:
         graph.toggle_drag_nodes(toggle_drag_nodes)
         graph.toggle_physics(False)
 
-        # make sure models folder exists
-        models_folder = os.path.join(
-            os.path.dirname(os.path.abspath(__name__)), "models"
-        )
-        if not os.path.isdir(models_folder):
-            os.mkdir(models_folder)
-
         # create path for model in models folder adjacent to this file
         self.model_path = os.path.join(
             self.config.default_dir,
@@ -346,32 +343,18 @@ class ModelMap:
         """
         Shows the model map
         """
+        model_map_name = f"{self.ticker.split()[0]}_{self.time_series}_model_map.html"
         try:
-            if os.path.exists(self.model_path):
-                if "tmp" in self.model_path or "Temp" in self.model_path:
-                    return self.network.show(self.model_path)
-                else:
-                    return self.network.show(
-                        f"{self.ticker.split()[0]}_{self.time_series}_model_map.html"
-                    )
-            elif os.path.exists(
-                os.path.dirname(__main__.__name__),
-                f"{self.ticker.split()[0]}_{self.time_series}_model_map.html",
-            ):
-                return self.network.show(
-                    os.path.dirname(__main__.__name__),
-                    f"{self.ticker.split()[0]}_{self.time_series}_model_map.html",
-                )
-            elif os.path.exists(
-                f"/canalyst/{self.ticker.split()[0]}_{self.time_series}_model_map.html"
-            ):
-                return self.network.show(
-                    f"/canalyst/{self.ticker.split()[0]}_{self.time_series}_model_map.html"
-                )
-        except:
-            print("ModelMap html file not found.")
-            return
-        return
+            if self.notebook:
+                return self.network.show(model_map_name)
+
+            else:
+                self.network.write_html(self.model_path)
+                model_map_path = self.model_path.lstrip("/")
+                webbrowser.open(f"file:///{model_map_path}")
+
+        except Exception as e:
+            print(f"Error in showing model map: {e}")
 
     def create_node_df(self):
         """
@@ -568,7 +551,7 @@ class Model:
         model_map = self.create_model_map(
             time_series_name=time_series_name,
             col_for_labels="time_series_name",
-            notebook=False,
+            notebook=True,
         )
 
         # list all the nodes in the model map
@@ -862,7 +845,7 @@ class Model:
         time_series_name: str = "MO_RIS_REV",
         col_for_labels: str = "time_series_name",
         tree: bool = True,
-        notebook: bool = False,
+        notebook: bool = True,
         common_time_series_names: Optional[Iterable] = None,
     ) -> ModelMap:
         """
@@ -1016,8 +999,12 @@ class Model:
             self.config.verify_ssl,
         )
 
-        df_new = pd.json_normalize(drivers)
-        df_driver_array = pd.DataFrame(df_new["time_series.names"])
+        df = pd.json_normalize(drivers)
+        if not df.empty:
+            df_driver_array = pd.DataFrame(df["time_series.names"])
+        else:
+            df_driver_array = pd.DataFrame(columns=["time_series.names"])
+
         df_drivers = df_driver_array.explode("time_series.names")
         df = df_drivers.groupby("time_series.names").first().reset_index()
         df.columns = ["time_series_name"]
