@@ -315,7 +315,7 @@ def get_data_set_from_mds(
             settings.BulkDataKeys.HISTORICAL_DATA,
         ]:
             # parquet values are set as strings by default, manually set to floats/ints
-            df["value"] = pd.to_numeric(df["value"])
+            df["value"] = pd.to_numeric(df["value"], errors="coerce")
             # parquet dates are set as datetime.date objects by default, set to strings
             df["period_end_date"] = df["period_end_date"].astype(str)
             df["period_start_date"] = df["period_start_date"].astype(str)
